@@ -5,4 +5,7 @@ pub mod discover;
 pub mod insert;
 
 /// Connects to db and decides what data will be generated
-pub mod spawn;
\ No newline at end of file
+pub mod spawn;
+
+/// checks if data_types are supported
+pub mod data_types;
\ No newline at end of file
