@@ -20,4 +20,20 @@ create table if not exists users
 	occured_at datetime null,
 	constraint users_address_id_fk
 		foreign key (address_id) references address (id)
-);
\ No newline at end of file
+);
+
+
+create table numeric_types
+(
+	id int auto_increment
+		primary key,
+	int_type int null,
+	smallint_type smallint null,
+	tinint_type tinyint null,
+	mediumint_type mediumint null,
+	bigint_type bigint null,
+	decimal_type decimal null,
+	float_type float null,
+	double_type double null
+);
+
